==> exo.jcr.framework.command-1.9.3-sources.jar: org/exoplatform/frameworks/jcr/cli/GetPropertyCommand.java <==
/*
 * Copyright (C) 2003-2007 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.frameworks.jcr.cli;

import javax.jcr.Node;
import javax.jcr.Property;

/**
 * Created by The eXo Platform SAS
 * 
 * @author Vitaliy Obmanjuk
 * @version $Id: $
 */

public class GetPropertyCommand extends AbstractCliCommand {

  @Override
  public boolean perform(CliAppContext ctx) {
    String output = "";
    try {
      String relPath = ctx.getParameter(0);
      Node currentNode = (Node) ctx.getCurrentItem();
      Property resultProperty = currentNode.getProperty(relPath);
      ctx.setCurrentItem(resultProperty);
      try {
        output = "Current property value: "
            + resultProperty.getValue().getString() + "\n";
      } catch (Exception e) {
        output = "Can't display the property value";
      }
    } catch (Exception e) {
      output = "Can't execute command - " + e.getMessage() + "\n";
    }
    ctx.setOutput(output);
    return false;
  }
}

==> exo.jcr.framework.command-1.10.13-sources.jar: org/exoplatform/frameworks/jcr/cli/GetPropertyCommand.java <==
/*
 * Copyright (C) 2003-2007 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.frameworks.jcr.cli;

import javax.jcr.Node;
import javax.jcr.Property;

/**
 * Created by The eXo Platform SAS
 * 
 * @author Vitaliy Obmanjuk
 * @version $Id: GetPropertyCommand.java 35179 2009-08-07 13:58:20Z pnedonosko $
 */

public class GetPropertyCommand extends AbstractCliCommand {

  @Override
  public boolean perform(CliAppContext ctx) {
    String output = "";
    try {
      String relPath = ctx.getParameter(0);
      Node currentNode = (Node) ctx.getCurrentItem();
      Property resultProperty = currentNode.getProperty(relPath);
      ctx.setCurrentItem(resultProperty);
      try {
        output = "Current property value: " + resultProperty.getValue().getString() + "\n";
      } catch (Exception e) {
        output = "Can't display the property value";
      }
    } catch (Exception e) {
      output = "Can't execute command - " + e.getMessage() + "\n";
    }
    ctx.setOutput(output);
    return false;
  }
}
